<?php
/**
 * Scroll article excerpt
 *
 * @package 	Scroll article excerpt
 * @subpackage 	mod_scroll_article_excerpt
 * @version   	4.0
 * @author    	Gopi Ramasamy
 * @copyright   Copyright (C) 2010 - 2021 www.gopiplus.com. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 *
 * http://www.gopiplus.com/extensions/2011/09/scroll-article-excerpt-joomla-module/
 */
 
namespace Joomla\Module\ScrollArticleExcerpt\Site\Helper;

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Access\Access;
use Joomla\Utilities\ArrayHelper;
use Joomla\Component\Content\Site\Model\ArticlesModel;

abstract class ScrollArticleExcerptHelper
{
	public static function getArticleList(&$params)
	{
		// Get an instance of the generic articles model
		$model = new ArticlesModel(array('ignore_request' => true));

		// Set application parameters in model
		$app       = Factory::getApplication();
		$appParams = $app->getParams();
		$model->setState('params', $appParams);

		// Set the filters based on the module params
		$model->setState('list.start', 0);
		$model->setState('list.limit', (int) $params->get('sae_count', 5));
		$model->setState('filter.published', 1);

		// This module does not use tags data
		$model->setState('load_tags', false);

		// Access filter
		$access     = !ComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = Access::getAuthorisedViewLevels(Factory::getUser()->get('id'));
		$model->setState('filter.access', $access);

		// Category filter
		$model->setState('filter.category_id', $params->get('sae_catid', array()));

		// Filter by language
		$model->setState('filter.language', $app->getLanguageFilter());

		// Filer by tag
		$model->setState('filter.tag', $params->get('sae_tag'), array());

		//  Featured switch
		switch ($params->get('sae_featured'))
		{
			case '1' :
				$model->setState('filter.featured', 'only');
				break;
			case '0' :
				$model->setState('filter.featured', 'hide');
				break;
			default :
				$model->setState('filter.featured', 'show');
				break;
		}

		// Set ordering
		$ordering = $params->get('sae_ordering', 'a.publish_up');
		$model->setState('list.ordering', $ordering);

		if (trim($ordering) === 'rand()')
		{
			$model->setState('list.ordering', Factory::getDbo()->getQuery(true)->Rand());
		}
		else
		{
			$direction = $params->get('sae_direction', 1) ? 'DESC' : 'ASC';
			$model->setState('list.direction', $direction);
			$model->setState('list.ordering', $ordering);
		}

		// Retrieve Content
		$items = $model->getItems();

		foreach ($items as &$item)
		{
			$item->readmore = strlen(trim($item->fulltext));
			$item->slug     = $item->id . ':' . $item->alias;

			if ($access || in_array($item->access, $authorised))
			{
				// We know that user has the privilege to view the article
				$item->link     = \JRoute::_(\ContentHelperRoute::getArticleRoute($item->slug, $item->catid, $item->language));
			}
			else
			{
				$item->link = new Uri(\JRoute::_('index.php?option=com_users&view=login', false));
				$item->link->setVar('return', base64_encode(\ContentHelperRoute::getArticleRoute($item->slug, $item->catid, $item->language)));
			}

			$item->introtext = \JHtml::_('content.prepare', $item->introtext, '', 'mod_articles_news.content');
		}
		return $items;
	}
}